==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Frestrict_senders-1.2-1.4.1.tar.gz: restrict_senders/data/config.sample.php <==
<?php


   global $restrictDomains, $restrictNumberOfRecipients, $restrictNumberOfEmailsPerDay,
          $rs_report_addresses, $rs_use_Vadmin_delete_link, $rs_debug,
          $restrictSubsequentMassEmails, $restrictSubsequentMassEmailsWhitelist,
          $account_disabled_message, $report_abuse_too_many_recipients_message,
          $report_abuse_too_many_today_message, $whitelisted_addresses, $rs_delimiter;



   // Set this to the maximum number of outgoing recipients any
   // one mail should have.  Set to zero to allow unlimited number
   // of recipients.
   //
   // Note that you may specify override values for this in the
   // "Login Manager" (vlogin) plugin if you are using that
   // by specifying the "vlogin_restrictNumberOfRecipients" setting
   // in the vlogin configuration.
   //
   $restrictNumberOfRecipients = 0;



   // Set this to the maximum number of outgoing emails that may
   // be sent by any one user in any one day.  Set to zero to 
   // allow unlimited number of emails.  Any user caught by this 
   // restriction will not be allowed to send any messages for 
   // the rest of the day unless an administrator manually removes 
   // the following setting from the user's preferences:
   //    todays_email_count
   //
   // Note that you may specify override values for this in the
   // "Login Manager" (vlogin) plugin if you are using that
   // by specifying the "vlogin_restrictNumberOfEmailsPerDay" setting
   // in the vlogin configuration.
   //
   $restrictNumberOfEmailsPerDay = 0;



   // This setting allows you to effectively turn off all sends
   // for any user who blasts out too many mass-recipient emails
   // in a fixed amount of time.  Once caught, an alert email is
   // sent to $rs_report_addresses (see below) (make sure you have 
   // not turned that address off when using this functionality, 
   // lest users have their accounts locked down and you won't 
   // know about it) and that account will no longer be able to 
   // send any more email (through SquirrelMail only) until an 
   // administrator manually removes the following preference from 
   // the user's preferences:
   //   USER_IS_POSSIBLE_SPAMMER  
   // 
   // This setting consists of three values separated by colons.
   // The first is the number of recipients that comprise the 
   // minimum threshold of a "mass email", the second is the 
   // number of emails that should trigger this functionality, 
   // and the third is the number of minutes within which the 
   // emails must be sent.
   //
   // For example, with a setting of 20:4:5, if a user sends 4 or 
   // more emails to 20 or more people within a 5 minute time
   // span, the user will be blocked from sending any more emails
   // until manually unlocked as described above.
   //
   // Set as an empty value to disable this functionality.
   //
   // Note that you may specify override values for this in the
   // "Login Manager" (vlogin) plugin if you are using that
   // by specifying the "vlogin_restrictSubsequentMassEmails"
   // setting in the vlogin configuration.
   //
   //$restrictSubsequentMassEmails = '20:4:5';
   $restrictSubsequentMassEmails = '';



   // You can exempt certain users from being banned per the 
   // $restrictSubsequentMassEmails setting by entering them
   // in this list.
   //
   // Note that you may specify override values for this in the
   // "Login Manager" (vlogin) plugin if you are using that
   // by specifying the "vlogin_restrictSubsequentMassEmailsWhitelist"
   // setting in the vlogin configuration.
   //
   $restrictSubsequentMassEmailsWhitelist = array(
//       'me@mydomain.com',
//       'joe_mass_mailer@example.com',
                                                 );



   // Users who have sent the maximum daily allotment of messages
   // per $restrictNumberOfEmailsPerDay or who have been banned
   // from sending mail per $restrictSubsequentMassEmails will still
   // be able to send messages to the white-listed addresses defined
   // here.  Any addresses listed here will also be exempt from any
   // domain restrictions defined in the send_restrictions.php file.
   //
   // The delimiter defined here should correspond to the mailbox/
   // host part separator for parsing the white-listed addresses.
   //
   // $whitelisted_addresses = array('helpdesk@example.org', 'support@example.org');
   $whitelisted_addresses = array();
   $rs_delimiter = '@';



   // Turn off/on functionality to check the addresses of 
   // all outgoing email addresses.  Set to 1 to enable, zero
   // to disable.  The rules for the checks performed are
   // defined in your send_restrictions.php file.
   //
   // Despite this setting's name, full recipient addresses
   // are subject to the rules you have defined.
   //
   // Also note that you may specify a different set of rules
   // for different users, domains, or user groupings by using
   // the "Login Manager" (vlogin) plugin and specifying the
   // "vlogin_restrict_senders_rules_file" setting in the
   // vlogin configuration, which must contain the full path 
   // to the desired rules file.
   //
   $restrictDomains = 0;



   // This is a list of one or more comma-separated email addresses
   // to which alert emails will be sent.  To disable alert emails,
   // make sure this setting is empty.
   //
   //$rs_report_addresses = '';
   $rs_report_addresses = 'postmaster';



   // You may create your own administrative alert messages below
   // if the defaults do not suit you.  Leave these blank to use
   // the default messages.
   //
   // You may use the following strings inside the message text,
   // such that they will be replaced with their corresponding 
   // values:
   //
   //   ###USERNAME###            --  offending username
   //   ###DOMAIN###              --  offending user's domain
   //   ###TO###                  --  To: header of the offending
   //                                 email message
   //   ###CC###                  --  Cc: header of the offending
   //                                 email message
   //   ###BCC###                 --  Bcc: header of the offending
   //                                 email message
   //   ###BODY###                --  The body of the offending 
   //                                 email message
   //
   // Only used with $report_abuse_too_many_today_message:
   //
   //   ###NUMBER_MAILS_TODAY###  --  number of emails allowed per day
   //
   // Only used with $report_abuse_too_many_recipients_message:
   //
   //   ###NUMBER_RECIPIENTS###   --  total number of recipients 
   //                                 in offending email message
   //
   // PLEASE NOTE that several of the substitutions available 
   // above will allow you to see the personal details of your
   // users' messages, and as such, you should be prepared to
   // have an appropriate privacy policy and terms of service
   // agreement before you use these.
   //
   // $report_abuse_too_many_recipients_message = '###USERNAME### has attempted to send a message with ###NUMBER_RECIPIENTS### recipients';
   // $report_abuse_too_many_today_message = '###USERNAME### has attempted to send more than ###NUMBER_MAILS_TODAY### emails today';
   //
   $report_abuse_too_many_recipients_message = '';
   $report_abuse_too_many_today_message = '';



   // It is possible to override the message displayed on screen
   // when a user is banned from sending any more messages (per
   // the $restrictSubsequentMassEmails setting).  You may specify
   // that message override here
   //
   $account_disabled_message = '';



   // If you use the Vadmin plugin, a link can be included
   // that redirects you to the page where you can delete
   // offending accounts
   //
   $rs_use_Vadmin_delete_link = 0;



   // Debug flag
   //
   //   0  --  off
   //   1  --
   //   2  --  load sender restriction rulesets dynamically
   //          (don't store in session)
   //   4  --  view any sender restriction rulesets found
   //          for the current user when sending a message
   //
   // This is a binary mask, so values may be combined (2 | 4 = 6)
   //
   $rs_debug = 0;

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Frestrict_senders-1.3-1.4.1.tar.gz: restrict_senders/data/config.sample.php <==
<?php


   global $restrictDomains, $restrictNumberOfRecipients, $restrictNumberOfEmailsPerDay,
          $rs_report_addresses, $rs_use_Vadmin_delete_link, $rs_debug,
          $restrictSubsequentMassEmails, $restrictSubsequentMassEmailsWhitelist,
          $account_disabled_message, $report_abuse_too_many_recipients_message,
          $report_abuse_too_many_today_message, $whitelisted_addresses, $rs_delimiter,
          $log_too_many_recipients, $log_too_many_today,
          $log_too_many_subsequent_mass_emails, $log_no_recipients;



   // Set this to the maximum number of outgoing recipients any
   // one mail should have.  Set to zero to allow unlimited number
   // of recipients.
   //
   // Note that you may specify override values for this in the
   // "Login Manager" (vlogin) plugin if you are using that
   // by specifying the "vlogin_restrictNumberOfRecipients" setting
   // in the vlogin configuration.
   //
   $restrictNumberOfRecipients = 0;



   // Set this to the maximum number of outgoing emails that may
   // be sent by any one user in any one day.  Set to zero to
   // allow unlimited number of emails.  Any user caught by this
   // restriction will not be allowed to send any messages for
   // the rest of the day unless an administrator manually removes
   // the following setting from the user's preferences:
   //    todays_email_count
   //
   // Note that you may specify override values for this in the
   // "Login Manager" (vlogin) plugin if you are using that
   // by specifying the "vlogin_restrictNumberOfEmailsPerDay" setting
   // in the vlogin configuration.
   //
   $restrictNumberOfEmailsPerDay = 0;



   // This setting allows you to effectively turn off all sends
   // for any user who blasts out too many mass-recipient emails
   // in a fixed amount of time.  Once caught, an alert email is
   // sent to $rs_report_addresses (see below) (make sure you have 
   // not turned that address off when using this functionality, 
   // lest users have their accounts locked down and you won't 
   // know about it) and that account will no longer be able to 
   // send any more email (through SquirrelMail only) until an 
   // administrator manually removes the following preference from 
   // the user's preferences:
   //   USER_IS_POSSIBLE_SPAMMER  
   // 
   // This setting consists of three values separated by colons.
   // The first is the number of recipients that comprise the 
   // minimum threshold of a "mass email", the second is the 
   // number of emails that should trigger this functionality, 
   // and the third is the number of minutes within which the 
   // emails must be sent.
   //
   // For example, with a setting of 20:4:5, if a user sends 4 or 
   // more emails to 20 or more people within a 5 minute time
   // span, the user will be blocked from sending any more emails
   // until manually unlocked as described above.
   //
   // Set as an empty value to disable this functionality.
   //
   // Note that you may specify override values for this in the
   // "Login Manager" (vlogin) plugin if you are using that
   // by specifying the "vlogin_restrictSubsequentMassEmails"
   // setting in the vlogin configuration.
   //
   //$restrictSubsequentMassEmails = '20:4:5';
   $restrictSubsequentMassEmails = '';



   // You can exempt certain users from being banned per the 
   // $restrictSubsequentMassEmails setting by entering them
   // in this list.
   //
   // Note that you may specify override values for this in the
   // "Login Manager" (vlogin) plugin if you are using that
   // by specifying the "vlogin_restrictSubsequentMassEmailsWhitelist"
   // setting in the vlogin configuration.
   //
   $restrictSubsequentMassEmailsWhitelist = array(
//       'me@mydomain.com',
//       'joe_mass_mailer@example.com',
                                                 );



   // Users who have sent the maximum daily allotment of messages
   // per $restrictNumberOfEmailsPerDay or who have been banned
   // from sending mail per $restrictSubsequentMassEmails will still
   // be able to send messages to the white-listed addresses defined
   // here.  Any addresses listed here will also be exempt from any
   // domain restrictions defined in the send_restrictions.php file.
   //
   // The delimiter defined here should correspond to the mailbox/
   // host part separator for parsing the white-listed addresses.
   //
   // $whitelisted_addresses = array('helpdesk@example.org', 'support@example.org');
   $whitelisted_addresses = array();
   $rs_delimiter = '@';



   // Turn off/on functionality to check the addresses of
   // all outgoing email addresses.  Set to 1 to enable, zero
   // to disable.  The rules for the checks performed are
   // defined in your send_restrictions.php file.
   //
   // Despite this setting's name, full recipient addresses
   // are subject to the rules you have defined.
   //
   // Also note that you may specify a different set of rules
   // for different users, domains, or user groupings by using
   // the "Login Manager" (vlogin) plugin and specifying the
   // "vlogin_restrict_senders_rules_file" setting in the
   // vlogin configuration, which must contain the full path 
   // to the desired rules file.
   //
   $restrictDomains = 0;



   // This is a list of one or more comma-separated email addresses
   // to which alert emails will be sent.  To disable alert emails,
   // make sure this setting is empty.
   //
   //$rs_report_addresses = '';
   $rs_report_addresses = 'postmaster';



   // You may create your own administrative alert messages below
   // if the defaults do not suit you.  Leave these blank to use
   // the default messages.
   //
   // You may use the following strings inside the message text,
   // such that they will be replaced with their corresponding 
   // values:
   //
   //   ###USERNAME###            --  offending username
   //   ###DOMAIN###              --  offending user's domain
   //   ###TO###                  --  To: header of the offending
   //                                 email message
   //   ###CC###                  --  Cc: header of the offending
   //                                 email message
   //   ###BCC###                 --  Bcc: header of the offending
   //                                 email message
   //   ###BODY###                --  The body of the offending 
   //                                 email message
   //
   // Only used with $report_abuse_too_many_today_message:
   //
   //   ###NUMBER_MAILS_TODAY###  --  number of emails allowed per day
   //
   // Only used with $report_abuse_too_many_recipients_message:
   //
   //   ###NUMBER_RECIPIENTS###   --  total number of recipients 
   //                                 in offending email message
   //
   // PLEASE NOTE that several of the substitutions available 
   // above will allow you to see the personal details of your
   // users' messages, and as such, you should be prepared to
   // have an appropriate privacy policy and terms of service
   // agreement before you use these.
   //
   // $report_abuse_too_many_recipients_message = '###USERNAME### has attempted to send a message with ###NUMBER_RECIPIENTS### recipients';
   // $report_abuse_too_many_today_message = '###USERNAME### has attempted to send more than ###NUMBER_MAILS_TODAY### emails today';
   //
   $report_abuse_too_many_recipients_message = '';
   $report_abuse_too_many_today_message = '';



   // It is possible to override the message displayed on screen
   // when a user is banned from sending any more messages (per
   // the $restrictSubsequentMassEmails setting).  You may specify
   // that message override here
   //
   $account_disabled_message = '';



   // If you'd like to log when users hit the limits defined
   // above for $restrictNumberOfRecipients,
   // $restrictNumberOfEmailsPerDay, or $restrictSubsequentMassEmails,
   // then turn on the corresponding setting below.
   // $log_no_recipients will log an event when the rules in
   // send_restrictions.php cause a message to be left with no
   // recipients (all recipients are blacklisted).
   // Note that logging is accomplished by using the Squirrel
   // Logger plugin, so you'll need to have that installed and
   // configured with an additional event type called
   // "RESTRICT_SENDERS".
   //
   $log_too_many_recipients = 0;
   $log_too_many_today = 0;
   $log_too_many_subsequent_mass_emails = 0;
   $log_no_recipients = 0;



   // If you use the Vadmin plugin, a link can be included
   // that redirects you to the page where you can delete
   // offending accounts
   //
   $rs_use_Vadmin_delete_link = 0;



   // Debug flag
   //
   //   0  --  off
   //   1  --  
   //   2  --  load sender restriction rulesets dynamically
   //          (don't store in session)
   //   4  --  view any sender restriction rulesets found
   //          for the current user when sending a message
   //
   // This is a binary mask, so values may be combined (2 | 4 = 6)
   //
   $rs_debug = 0;
